@@ -28,6 +28,8 @@ Eric Lease Morgan <emorgan@nd.edu>
 APPLICATIONDIRECTORY = 'rdr'
 CONFIGURATIONFILE    = '.rdrrc'
 READERLIBRARY        = 'reader-library'
+MALLETHOME           = 'mallet'
+TIKAHOME             = 'tika-server.jar'
 
 # remote library
 REMOTELIBRARY = 'http://library.distantreader.org'
@@ -53,11 +55,99 @@ MODEL = 'en_core_web_sm'
 MALLETZIP = 'http://library.distantreader.org/apps/mallet.zip'
 MALLETBIN = 'bin/mallet'
 
+# tika server
+TIKADOWNLOAD = 'http://library.distantreader.org/apps/tika-server.jar'
+
 
 # require
 import click
 
 
+# create or re-create the preferences/settings
+def initializeConfigurations() :
+
+	# require
+	from configparser import ConfigParser
+	from pathlib      import Path
+
+	# initialize
+	configurations       = ConfigParser()
+	applicationDirectory = Path.home()
+	configurationFile    = applicationDirectory/CONFIGURATIONFILE
+
+	# define defaults, and...
+	configurations[ "RDR" ] = { "localLibrary" : Path.home()/READERLIBRARY, 
+								"malletHome"   : Path.home()/MALLETHOME,
+								"tikaHome"     : Path.home()/TIKAHOME }
+
+	# save them
+	with open( str( configurationFile ), 'w' ) as handle : configurations.write( handle )
+
+	# create the library directory
+	( Path.home()/READERLIBRARY ).mkdir( exist_ok=True )
+
+
+# read configurations
+def configuration( name ) :
+
+	# require
+	from configparser import ConfigParser
+	from pathlib      import Path
+
+	# initialize
+	applicationDirectory = Path.home()
+	configurationFile    = applicationDirectory/CONFIGURATIONFILE	
+	configurations       = ConfigParser()
+	
+	# read configurations file
+	configurations.read( str( configurationFile ) )
+	
+	# get configurations
+	localLibrary = configurations[ 'RDR' ][ 'localLibrary' ]
+	malletHome   = configurations[ 'RDR' ][ 'malletHome' ] 
+	tikaHome     = configurations[ 'RDR' ][ 'tikaHome' ] 
+	
+	# done
+	if   name == 'localLibrary' : return( Path( localLibrary ) )
+	elif name == 'malletHome'   : return( Path( malletHome ) )
+	elif name == 'tikaHome'     : return( Path( tikaHome ) )
+	else :
+	
+		# unknown configuration
+		click.echo( f"Error: Unknown value for configuration name: { name }. Call Eric.", err=True )
+		exit()
+		
+
+# handle model not found error
+def modelNotFound() :
+	
+	# notify
+	click.echo( "Error: Langauge model not found.", err=True )
+	click.echo()
+	click.echo( f"This functions requires a spaCy langauge model ({ MODEL}) to be installed. This only has to be done once, and after the model has been installed you can run the command again.", err=True )
+	click.echo()
+	click.echo( 'Do you want to install the model now? [yn] ', err=True, nl=False )
+	
+	# get input
+	c = click.getchar()
+	click.echo()
+	
+	# branch accordingly; yes
+	if c == 'y' :
+
+		# require and do the work
+		from os import system
+		system( 'python -m spacy download ' + MODEL )
+	
+	# no
+	elif c == 'n' : click.echo( "Okay, but installing the model is necessary for this function to work. You'll be asked again next time.", err=True )
+
+	# error
+	else : click.echo( '???' )
+	
+	# done
+	exit()
+
 # make sure the NLTK is sane
 def checkForPunkt() :
 
@@ -78,40 +168,17 @@ def checkForCarrel( carrel ) :
 	if not directory.is_dir() :
 		
 		# error
-		click.echo( f"The carrel, { carrel }, does not seem to be in your local library. Are you sure you entered its name correctly? Try 'rdr catalog' to make sure.", err=True )
+		click.echo( ('''
+  WARNING: The carrel, %s, does not seem to be in your local
+  library. Are you sure you entered its name correctly? Try 'rdr
+  catalog' to make sure.
+
+  Alternatively, maybe you have moved the library and your settings
+  are not up-to-date. If so, then use 'rdr get -s local' and/or
+  'rdr set -s local' to rectify the issue.
+''' % carrel ), err=True )
 		exit()
 
 	
-# read configurations
-def configuration( name ) :
-
-	# require
-	from configparser import ConfigParser
-	from pathlib      import Path
-
-	# initialize
-	applicationDirectory = Path( click.get_app_dir( APPLICATIONDIRECTORY ) )
-	configurationFile    = applicationDirectory / CONFIGURATIONFILE
-	configurations       = ConfigParser()
-	
-	# try to read configurations
-	configurations.read( str( configurationFile ) )
-	
-	# try to get localLibrary
-	try : localLibrary = configurations[ 'RDR' ][ 'localLibrary' ]
-	except KeyError :
-		click.echo( "Error: Key error. The location of your local study carrels has not been set. Please run 'rdr set local'.", err=True )
-		exit()
-		
-	# try to get MALLET's home
-	malletHome = configurations[ 'RDR' ][ 'malletHome' ] 
-	
-	# done
-	if   name == 'localLibrary' : return( Path( localLibrary ) )
-	elif name == 'malletHome'   : return( Path( malletHome ) )
-	else :
-		click.echo( f"Error: Unknown value for configuration name: { name }. Call Eric.", err=True )
-		exit()
-		
 
 
