@@ -34,18 +34,26 @@ def download( carrel ) :
 	localLibrary  = configuration( 'localLibrary' )
 
 	# get the remote zip file; needs error checking
-	click.echo( "Getting study carrel... ", err=True )
+	click.echo( "\n  INFO: Downloading remote study carrel... ", err=True )
 	response = get( REMOTELIBRARY + '/' + CARRELS + '/' + carrel + '/' + ZIPFILE )
 	
 	# initialize a temporary file and write to it
-	click.echo( "Saving study carrel... ", err=True )
+	click.echo( "  INFO: Saving study carrel... ", err=True )
 	handle = TemporaryFile()
 	handle.write( response.content )
 	
 	# unzip the temporary file and close it, which also deletes it
-	click.echo( "Unziping study carrel... " )
+	click.echo( "  INFO: Unziping study carrel... ", err=True )
 	with ZipFile( handle, 'r' ) as zip : zip.extractall( str( localLibrary ) )
 	handle.close()
 
 	# done
-	click.echo( "Done." )
+	click.echo( ( '''  INFO: Done. You may now any of the RDR commands. For example:
+
+	* rdr info %s
+	* rdr bib %s
+	* rdr cluster %s
+	* rdr ngrams %s -s 2 -c
+	* rdr wrd %s -c
+	* rdr tm %s
+''' ) % ( carrel, carrel, carrel, carrel, carrel, carrel, ), err=True )
