@@ -4,7 +4,7 @@ from rdr import *
 
 # config
 @click.command()
-@click.option('-s', '--setting', default='local', type=click.Choice( [ 'local', 'mallet' ] ), help='output the given setting')
+@click.option('-s', '--setting', default='local', type=click.Choice( [ 'local', 'mallet', 'tika' ] ), help='output the given setting')
 def get( setting ) :
 
 	"""Echo the values denoted by the set subcommand.
@@ -16,7 +16,8 @@ def get( setting ) :
 	See also: rdr set --help"""
 	
 	# branch accordingly
-	if   setting == 'local' : click.echo( str( configuration( 'localLibrary' ) ) )
+	if   setting == 'local'  : click.echo( str( configuration( 'localLibrary' ) ) )
 	elif setting == 'mallet' : click.echo( str( configuration( 'malletHome' ) ) )
+	elif setting == 'tika'   : click.echo( str( configuration( 'tikaHome' ) ) )
 	
 	
