@@ -42,8 +42,8 @@ def ngrams( carrel, size, query, count, location ) :
 		
 		# read local data
 		localLibrary = configuration( 'localLibrary' )
-		stopwords    = open( str( localLibrary/carrel/ETC/STOPWORDS ) ).read().split()
-		text         = open( str( localLibrary/carrel/ETC/CORPUS ) ).read()
+		stopwords    = open( str( localLibrary/carrel/ETC/STOPWORDS ), encoding='utf-8' ).read().split()
+		text         = open( str( localLibrary/carrel/ETC/CORPUS ), encoding='utf-8' ).read()
 	
 	# remote
 	elif location == 'remote' :
@@ -121,7 +121,7 @@ def ngrams( carrel, size, query, count, location ) :
 		for ngram in ngrams :
 			
 			# create a record and output
-			record = str( ngram[ 1 ] ) + '\t' + '\t'.join( list( ngram[ 0 ] ) )
+			record = '\t'.join( list( ngram[ 0 ] ) ) + '\t' + str( ngram[ 1 ] )
 			click.echo( record )
 		
 	# power user
